function cashflowvalues=CF(T_life, T_build, FR, FP, V_ship, CAP, lambda, gamma, newbuild_price, interest_rate, OPEX_nonfuel_yearly)
% This function generateas the deterministic cash flow for the base case ship design

%% Assumptions
T_interests=T_life; % Interests are paid over the lifetime

LTD=80000;          % Light dispalcement
scrap_price=400;    % Scrap price per light ship displacement


%% Logging vectors
revenue=zeros(1,T_life+T_build);
CAPEX=zeros(1,T_life+T_build);
OPEX_nonfuel=zeros(1,T_life+T_build);
VOYEX=zeros(1,T_life+T_build);
cash_flows=zeros(1,T_life+T_build);


%% Deterministic cash flow calculation
for i=1:T_life+T_build
    
    % Revenue yearly
    if i>T_build && i<T_life+T_build
        revenue(i)=yearly_revenue(FR(i),V_ship(i),CAP, lambda);
    elseif i == T_life+T_build
        revenue(i)=yearly_revenue(FR(i),V_ship(i),CAP, lambda) + scrap_price*LTD;
    end
    
    
    % CAPEX building costs - assume linearly spread over building time
    % CAPEX also includes interests
    if i<=T_build
        CAPEX(i)=(newbuild_price/T_build);
    elseif i<=T_build+T_interests
        CAPEX(i)=newbuild_price*interest_rate;
    end
 
   
    % OPEX nonfuel
    if i>T_build && i<T_life+T_build
        OPEX_nonfuel(i)=OPEX_nonfuel_yearly;
    else
        OPEX_nonfuel(i)=0;
    end
    
    
    % VOYEX fuel
    if i>T_build && i<T_life+T_build
        VOYEX(i)=fuel_costs_yearly(FP(i), V_ship(i), CAP, gamma);
    else
        VOYEX(i)=0;
    end
    
    %Cash flow calculation
    cash_flows(i)=revenue(i)-CAPEX(i)-OPEX_nonfuel(i)-VOYEX(i);
end

cashflowvalues=cash_flows;

end