function cashflows = CF_in_options(price_factor, T_life, T_build, FR, FP, V_ship, CAP, lambda, gamma, newbuild_price, interest_rate, OPEX_nonfuel_yearly,fuel_consumption_factor)
% Calculates the cash flow for the "in" options analyses

% Cap is vector
% fuel price is vector

%% Time parameters
T_interests=T_life;

LTD=80000;
scrap_price=400;

%% Logging files
revenue=zeros(1,T_life+T_build);
CAPEX=zeros(1,T_life+T_build);
OPEX_nonfuel=zeros(1,T_life+T_build);
VOYEX=zeros(1,T_life+T_build);
cash_flows=zeros(1,T_life+T_build);

%% Deterministic cash flow calculation
for i=1:T_life+T_build
    
    % Revenue yearly
    if i>T_build && i<T_life+T_build
        revenue(i)=yearly_revenue(FR(i),V_ship(i),CAP(i), lambda);
    elseif i == T_life+T_build
        revenue(i)=yearly_revenue(FR(i),V_ship(i),CAP(i), lambda) + scrap_price*LTD;
    end
    
    
    % CAPEX building costs - assume linearly spread over building time
    % CAPEX also includes interests
    if i<=T_build
        CAPEX(i)=(newbuild_price/T_build);
    elseif i<=T_build+T_interests
        CAPEX(i)=newbuild_price*interest_rate;
    end
    
    % CAPEX also includes expansion option price
    if i>T_build+2
        if CAP(i)-CAP(i-1)==2000
            CAPEX(i)=CAPEX(i)+newbuild_price*price_factor;
        end
    end
   
    % OPEX nonfuel
    if i>T_build && i<T_life+T_build
        OPEX_nonfuel(i)=OPEX_nonfuel_yearly;
    else
        OPEX_nonfuel(i)=0;
    end
    
    
    % VOYEX fuel
    if i>T_build && i<T_life+T_build
        VOYEX(i)=fuel_costs_yearly(FP(i), V_ship(i), CAP(i), gamma)*fuel_consumption_factor(i);
    else
        VOYEX(i)=0;
    end
    
    %Cash flow calculation
    cash_flows(i)=revenue(i)-CAPEX(i)-OPEX_nonfuel(i)-VOYEX(i);
end

cashflows=cash_flows;

end

