%% expansion option valuation
clear all
clc

%% Collecting parameters
[dr, ir, CAP,...
    V_ship_design, lambda, gamma, Market_rate, OPEX_nonfuel_yearly,...
    HFO_price] = parameters_conainer_case_continuous();

[T_build, T_life]=parameters_container_case_discrete();
total_time = T_build+ T_life;
newbuild_price=newbuild_price_function(CAP);

%% Stochastic simulation input
nSim=2000;    % Number of simulations

% Stochastic processes inputs
[drift_market,sigma_market,drift_fuel,sigma_fuel,deltat]=parameters_stochastic();
start_market=Market_rate;
start_fuel=HFO_price;

%% VVectors for writing NPVs
NPV_log=zeros(1,nSim);
count_expansion=0;
threshold=OPEX_nonfuel_yearly+newbuild_price*ir;

%% Monte Carlo Simulation
for j=1:nSim

    %% on option
        market_scenario=GBM_market(start_market,drift_market,sigma_market,total_time);
        fuel_scenario=GBM_fuel(start_fuel,drift_fuel,sigma_fuel,total_time);
        speed_scenario=V_ship_design.*ones(1,total_time);

        CF_stochastic1=CF(T_life, T_build, market_scenario, fuel_scenario, speed_scenario, CAP, lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly);
        profit_margin1=profit_margin(T_life, T_build, market_scenario, fuel_scenario, speed_scenario, CAP, lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly);


    %% "On" option valuation cash flow
        CF_on=CF_on_option(CF_stochastic1, T_build, total_time,threshold);
    
        
    %% Expansion option

        profit_margin_expansion_factor=1.3;
        fuel_increase=0.05;
        price_fraction=0.05;
        
        expansion_year=expansion_option_year(profit_margin1, T_build, total_time,profit_margin_expansion_factor);
        expansion_vector=zeros(1,total_time);
        CAP_vector=CAP.*ones(1,total_time);
        
        cash_flow_in_expansion=CF_on;
        
        %% If expansion
        if expansion_year>0
            count_expansion=count_expansion+1;
                for m=expansion_year:total_time
                    expansion_vector(m)=1;
                end

            fuel_consumption_factor=ones(1,total_time)+(fuel_increase)*expansion_vector;
            CAP_new=CAP_vector+2000*expansion_vector;

            cash_flow_in_expansion=CF_in_options(price_fraction,T_life, T_build, market_scenario, fuel_scenario, speed_scenario, CAP_new, lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly,fuel_consumption_factor);
        end
        
        %% If expansion finished
        CF_in_tot=CF_on_option_after_in(expansion_year,cash_flow_in_expansion, T_build, total_time,threshold);
        
    %% NPV calculations
        NPV_log(j)=NPV(CF_in_tot,dr,total_time);

end

%% Performance calculations
NPV_mean_in_option=mean(NPV_log)
exspansion_fraction=count_expansion/nSim
ten_percentile = prctile(NPV_log,10)
ninety_percentile=prctile(NPV_log,90)