%% "In" option analysis for fuel switch option valuation
clear all
clc

%% Collecting parameters
[dr, ir, CAP,...
    V_ship_design, lambda, gamma, Market_rate, OPEX_nonfuel_yearly,...
    HFO_price] = parameters_conainer_case_continuous();

[T_build, T_life]=parameters_container_case_discrete();
total_time = T_build+ T_life;

instalaltion_price=10^7; % fuel switch installation cost
newbuild_price1=newbuild_price_function(CAP)+instalaltion_price;
newbuild_price2=newbuild_price_function(CAP);

%% Stochastic simulation input
nSim=2000;    % Number of simulations

LNG_price_start=700; % Price of LNG per HFO metric tonne equivalent.
HFO_price_start=500; % Price of HFO per metric tonnes

% Stochastic processes inputs
[drift_market,sigma_market,drift_fuel,sigma_fuel,deltat]=parameters_stochastic();
start_market=Market_rate;
start_fuel1=HFO_price;
start_fuel2=LNG_price_start;

kappa=0.5; % Mean reversion factor


%% Vectors for writing NPVs
NPV_log1=zeros(2,nSim);

threshold1=OPEX_nonfuel_yearly+newbuild_price1*ir;
threshold2=OPEX_nonfuel_yearly+newbuild_price2*ir;

count_retrofit=0;

%% Monte Carlo Simulation
for j=1:nSim

        % Generating market, fuel and speed scenarios
        market_scenario=GBM_market(start_market,drift_market,sigma_market,total_time);
        [fuel_scenario1,fuel_scenario2]=stochastic_fuels(start_fuel1, start_fuel2, drift_fuel, kappa, sigma_fuel, total_time);
        speed_scenario=V_ship_design.*ones(1,total_time);
        
        fuel_scenario_min=zeros(1,total_time); % matrix for storing values
       
        fuel_increase=0.02;     % assuming a 2% increase in fuel consumption if the option is exercised
        contanier_tank_displ=0.05; % assuming that the LNG tanks take up 5% of the container space
        
        % choosing the cheapest fuel
        for i=1:total_time
            fuel_scenario_min(i)=min(fuel_scenario1(i),fuel_scenario2(i));
        end


        
%% HFO - LNG switch from day 1 (notation "1")
       
        fuel_consumption_factor=ones(1,total_time)+(fuel_increase)*ones(1,total_time);
        CAP_new=CAP.*ones(1,total_time)-(contanier_tank_displ.*ones(1,total_time));

        cash_flow_in_switch1=CF_in_options(0,T_life, T_build, market_scenario, fuel_scenario_min, speed_scenario, CAP_new, lambda, gamma, newbuild_price1, ir, OPEX_nonfuel_yearly,fuel_consumption_factor);
        
        % "on" options analysis is performed first
        install_year=2;
        CF_in_tot1=CF_on_option_after_in(install_year,cash_flow_in_switch1, T_build, total_time,threshold1);

        %NPV calculations
        NPV_log1(1,j)=NPV(CF_in_tot1,dr,total_time);

  
        
%% HFO - LNG option to switch later by retrofit (notation "2")
        
        fuel_scenario_HFO=fuel_scenario1; % matrix for storing values

        % First "On" option valuation cash flow
        CF_stochastic1=CF(T_life, T_build, market_scenario, fuel_scenario_HFO, speed_scenario, CAP, lambda, gamma, newbuild_price1, ir, OPEX_nonfuel_yearly);
        CF_on=CF_on_option(CF_stochastic1, T_build, total_time,threshold2);
        
        
        % First "On" option valuation cash flow
        fuel_diff_factor_switch=0.20;    % switch when the  (HFO-LNG)/HFO > is this
        price_fraction=0.05;    % price of the retrofit
       
        switch_vector=zeros(1,total_time);
        CAP_vector=CAP.*ones(1,total_time);
                
        fuel_difference=(fuel_scenario1-fuel_scenario2)./fuel_scenario1; % relative difference (HFO - LNG)
        retrofit_year=retrofit_option_year(fuel_difference, T_build, total_time,fuel_diff_factor_switch);
        
        cash_flow_in_switch2=CF_on;
        fuel_switch_vector=zeros(1,total_time);
        
        %% if switch
        if retrofit_year>0
            count_retrofit=count_retrofit+1;
                for m=retrofit_year:total_time
                     fuel_switch_vector(m)=1;
                end
        
            fuel_scenario_after_switch=fuel_scenario_HFO;
            for i=retrofit_year:total_time
            fuel_scenario_after_switch(i)=min(fuel_scenario1(i),fuel_scenario2(i));
            end    
                
            fuel_consumption_factor_retrofit=ones(1,total_time)+(fuel_increase)*fuel_switch_vector;
            CAP_new_retrofit=CAP_vector-contanier_tank_displ.*fuel_switch_vector;

            cash_flow_in_switch2=CF_in_options(price_fraction,T_life, T_build, market_scenario, fuel_scenario_after_switch, speed_scenario, CAP_new_retrofit, lambda, gamma, newbuild_price2, ir, OPEX_nonfuel_yearly,fuel_consumption_factor_retrofit);
        end
        %% if switch finished
        
        CF_in_tot2=CF_on_option_after_in(retrofit_year,cash_flow_in_switch2, T_build, total_time,threshold2);        
        
        % NPV calculations
        NPV_log1(2,j)=NPV(CF_in_tot2,dr,total_time);       

        
end

%% Performance calculations

% Flexibility from year 1
NPV_mean_in_option1=mean(NPV_log1(1,:))
ten_percentile1 = prctile(NPV_log1(1,:),10)
ninety_percentile1=prctile(NPV_log1(1,:),90)

% Option to retrofit later
NPV_mean_in_option2=mean(NPV_log1(2,:))
exspansion_fraction2=count_retrofit/nSim
ten_percentile2 = prctile(NPV_log1(2,:),10)
ninety_percentile2=prctile(NPV_log1(2,:),90)
