%% "On" options analysis, lay-up
clear all
clc

%% Collecting parameters
[dr, ir, CAP,...
    V_ship_design, lambda, gamma, Market_rate, OPEX_nonfuel_yearly,...
    HFO_price] = parameters_conainer_case_continuous();

[T_build, T_life]=parameters_container_case_discrete();
total_time = T_build+ T_life;
newbuild_price=newbuild_price_function(CAP);

%% Stochastic simulation input
nSim=20000;    % Number of simulations

% Stochastic processes inputs
[drift_market,sigma_market,drift_fuel,sigma_fuel,deltat]=parameters_stochastic();
start_market=Market_rate;
start_fuel=HFO_price;

%% VVectors for writing NPVs
NPV_log=zeros(1,nSim);

%% Monte Carlo Simulation
for j=1:nSim
    
    % Generating scenarios
    market_scenario=GBM_market(start_market,drift_market,sigma_market,total_time);
    fuel_scenario=GBM_fuel(start_fuel,drift_fuel,sigma_fuel,total_time);
    speed_scenario=V_ship_design.*ones(1,total_time); % constant

    % Generating cash flows from the scenarios
    CF_stochastic1=CF(T_life, T_build, market_scenario, fuel_scenario, speed_scenario, CAP, lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly);

    %% "On" option valuation cash flow
    threshold=OPEX_nonfuel_yearly+newbuild_price*ir; % calculating the threshold
    CF_on=CF_on_option(CF_stochastic1, T_build, total_time,threshold); % calculating the post lay-up cash flows
    
    %% NPV calculations
    NPV_log(j)=NPV(CF_on,dr,total_time);

end

%% Output data
figure(4);
cdfplot(NPV_log);
xlim([-2*10^9 3*10^9]);

NPV_mean_on_option=mean(NPV_log)
ten_percentile = prctile(NPV_log,10)
ninety_percentile=prctile(NPV_log,90)
