%% Screening model
clear all
clc

%% Input data
% Collecting parameters
[dr, ir, CAP,...
    V_ship_design, lambda, gamma, Market_rate, OPEX_nonfuel_yearly,...
    HFO_price] = parameters_conainer_case_continuous();

[T_build, T_life]=parameters_container_case_discrete();
total_time = T_build+ T_life;

%% Stochastic simulation input
nSim=2000;    % Number of simulations

% Stochastic processes inputs
[drift_market,sigma_market,drift_fuel,sigma_fuel,deltat]=parameters_stochastic();
start_market=Market_rate;
start_fuel=HFO_price;

% Testvectors for screening
capacity_testvector=15000:1000:25000;
speed_testvector=15:1:25;

%% Vectors for writing NPVs
NPV_log=zeros(length(capacity_testvector),length(speed_testvector));

a=1;
for c=15000:1000:25000          % capacity
    b=1;
    for s=15:1:25               % speed
    
        %% Monte Carlo Simulation
        NPV_dist_log=zeros(1,nSim);
        
        for j=1:nSim

            market_scenario=GBM_market(start_market,drift_market,sigma_market,total_time);
            fuel_scenario=GBM_fuel(start_fuel,drift_fuel,sigma_fuel,total_time);
            speed_scenario=s.*ones(1,total_time);
            
            newbuild_price=newbuild_price_function(CAP);
            threshold=OPEX_nonfuel_yearly+newbuild_price*ir;
            
            % CF_stochastic=CF(market_scenario,fuel_scenario);
            CF_stochastic1=CF(T_life, T_build, market_scenario, fuel_scenario, speed_scenario, c,...
                lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly);


            %% "On" option valuation cash flow
            CF_on=CF_on_option(CF_stochastic1, T_build, total_time,threshold);


            %% NPV calculations
            NPV_dist_log(j)=NPV(CF_on,dr,total_time);

        end
        % Storing the calculated ENPV calue
        NPV_log(a,b)=mean(NPV_dist_log);
        
        b=b+1;
    end
    a=a+1;
end


%% Plots
% post processing of data here
createfigure_screening(speed_testvector, capacity_testvector, NPV_log);
