%% Stochastic base case analysis
clear all
clc

%% Input data
% Collecting parameters
[dr, ir, CAP,...
    V_ship_design, lambda, gamma, Market_rate, OPEX_nonfuel_yearly,...
    HFO_price] = parameters_conainer_case_continuous();

[T_build, T_life]=parameters_container_case_discrete();
total_time = T_build+ T_life;
newbuild_price=newbuild_price_function(CAP);

%% Stochastic simulation input
nSim=20000;    % Number of simulations

% Stochastic processes inputs
[drift_market,sigma_market,drift_fuel,sigma_fuel,deltat]=parameters_stochastic();
start_market=Market_rate;
start_fuel=HFO_price;

% Logging files
NPV_log=zeros(1,nSim);

%% Monte Carlo Simulation
for j=1:nSim

market_scenario=GBM_market(start_market,drift_market,sigma_market,total_time);
fuel_scenario=GBM_fuel(start_fuel,drift_fuel,sigma_fuel,total_time);
%speed_scenario=GBM_fuel(start_speed,drift_speed,sigma_speed,total_time);
speed_scenario=V_ship_design.*ones(1,total_time);

% CF_stochastic=CF(market_scenario,fuel_scenario);
CF_stochastic=CF(T_life, T_build, market_scenario, fuel_scenario, speed_scenario, CAP, lambda, gamma, newbuild_price, ir, OPEX_nonfuel_yearly);
NPV_log(j)=NPV(CF_stochastic,dr,total_time);

end

%% Plots and output data
figure(3);
cdfplot(NPV_log);
xlim([-2*10^9 3*10^9]);
NPV_mean=mean(NPV_log)